@@ -1,6 +1,6 @@
 
 /*
- *	@(#)mail_reader.c	1.24 6/29/94
+ *	@(#)mail_reader.c	1.27 10/23/94
  *
  *	(c) Copyright 1993-1994 by Mark Grant. All right reserved.
  *	The author assumes no liability for damages resulting from the 
@@ -234,6 +234,11 @@ MESSAGE	*m;
 	a = address;
 	s = m->sender;
 
+	/* Firewall */
+
+	if (!s)
+		return;
+
 	/* Ignore spaces */
 
 	while (*s == ' ' || *s == '\t')
@@ -428,10 +433,20 @@ MESSAGE	*m;
 	/* These are the only two common time formats I've come across */
 
 #ifndef SYSV
-	if (*(m->date) > '9') 
-		strptime (m->date, "%a %h %d %T %Y", &t);
-	else
-		strptime (m->date, "%d %b %y %T", &t);
+	if (*(m->date) > '9') {
+		if (m->date[20] > '9')  {
+			strptime (m->date, "%a %h %d %T", &t);
+			strptime (m->date+23, "%Y", &t);
+		}
+		else
+			strptime (m->date, "%a %h %d %T %Y", &t);
+	}
+	else {
+		if (m->date[7] == '1')
+			strptime (m->date, "%d %b %Y %T", &t);
+		else
+			strptime (m->date, "%d %b %y %T", &t);
+	}
 
 	return timegm (&t);
 #else
@@ -767,13 +782,6 @@ int	kill_messages;
 
 		/* If some lines, read them */
 
-		if (!killed) {
-			add_to_message_list_end (&messages,m);
-		}
-		else {
-			add_to_deleted (m);
-		}
-
 		if (lines > 0 || method != LINE_COUNT) {
 
 			finished = FALSE;
@@ -843,6 +851,13 @@ int	kill_messages;
 			}
 		}
 
+		if (!killed) {
+			add_to_message_list_end (&messages,m);
+		}
+		else {
+			add_to_deleted (m);
+		}
+
 		m->time_secs = get_time (m);
 
 		/* Look for next From line */
